#!/usr/bin/env python
from abipy.abilab import abiopen
import abipy.data as abidata
import matplotlib.pyplot as plt
import numpy as np

flist = ["tz2_2o_DS12_GSR.nc", "tz2_2o_DS22_GSR.nc"]
flist_gap = ["tz2_2o_DS13_FATBANDS.nc", "tz2_2o_DS23_FATBANDS.nc"]


gspec = dict(width_ratios=[2, 1], height_ratios=[1, 1])
fig, ax = plt.subplot_mosaic([['full0', 'gap0'], ['full5', 'gap5']],
                             gridspec_kw=gspec, figsize=(12, 8),
                             constrained_layout=True)
ax_list = ['full0', 'full5']
ax_gap_list = ['gap0', 'gap5']
for j in range(2):
    full = abiopen(flist[j]).ebands
    full.set_fermie_to_vbm()
    full.plot(with_gaps=False, ylims=(-3.0, 3.0), ax=ax[ax_list[j]], show=False)

    gap = abiopen(flist_gap[j]).ebands
    gap.set_fermie_to_vbm()
    gap.plot(with_gaps=True, ylims=(-1.0, 1.0), ax=ax[ax_gap_list[j]], show=False)


ax['full5'].set_title('5 GPa')
ax['full0'].set_title('0 GPa')
ax['gap5'].set_xticks([0, 17, len(gap.kpoints)-1])
ax['gap5'].set_xticklabels(['0.5H', 'A', '0.5L'])
ax['gap0'].set_xticks([0, 17, len(gap.kpoints)-1])
ax['gap0'].set_xticklabels(['0.5H', 'A', '0.5L'])

plt.savefig('tz2_2_bandstructure.pdf')
plt.show()



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite.
keywords = [
]

#: List of input files
inp_files = [
    "tatdep1_1.abi",
    "tatdep1_2.abi",
    "tatdep1_3.abi",
    "tatdep1_4.abi",
    "tatdep1_5.abi",
]



#!/usr/bin/env python
"""Search for inlined CPP macros in ABINIT src files"""
from __future__ import unicode_literals, division, print_function, absolute_import

__author__  = "M. Giantomassi"

import os
import re
import sys

from abirules_tools import find_src_dirs

# Files that will be checked.
re_srcfile = re.compile("\.([Ff]|[Ff]90|finc)$")

def is_srcfile(dirpath, fname):
    return re_srcfile.search(fname)

# List of macros that should not be inlined with if statements or other instructions.
# These macros are defined in shared/common/src/incs/abi_common.h
#
MACRO_NAMES = [
  "ABI_MALLOC",
  "ABI_MALLOC_SCALAR",
  "ABI_FREE_SCALAR",
  "ABI_FREE",
  "ABI_STAT_MALLOC",
  "ABI_MALLOC_OR_DIE",
  "ABI_MOVE_ALLOC",
  "ABI_MALLOC_TYPE_SCALAR",
  "ABI_CALLOC",
  "ABI_ICALLOC",
  "ABI_CALLOC_OR_DIE",
  "ABI_FREE_NOCOUNT",
  "ABI_MALLOC_IFNOT",
  "ABI_SFREE",
  "ABI_REMALLOC",
  "ABI_RECALLOC",
  "ABI_MALLOC_RAND",
]

# Regular expressions for each macro.
#regexps = dict()
#
#for name in MACRO_NAMES:
#    regexps[name] = re.compile(name + " ?\(.*\)")
#    #regexps[name] = re.compile(name + "\(.*\)") blanks between macro name and () are not permitted


def wrong_string(string):
    """Return 0 if input string does not contain inlined macros else 0"""
    s = string.strip().upper()
    if s.startswith("!"): return 0
    for macro_name in MACRO_NAMES:
        if macro_name not in s: continue
        #pattern = regexps[macro_name]
        if s.startswith("IF") and "THEN " not in s:
            return 1

    return 0


def test_wrong_string():

    strings_and_retcode = [
       ("if (.True.) ABI_MALLOC(dummy_atifc(3))", 1),
       ("!if (.True.) ABI_MALLOC(dummy_atifc(3))", 0),
       ("if (allocated(dummy_atifc)) ABI_FREE(dummy_atifc)", 1)
    ]

    failed = 0
    for (string, expected_retcode) in strings_and_retcode:
        retcode = wrong_string(string)
        if retcode != expected_retcode:
            failed += 1
            print("Failed test for string:", string)

    if failed:
        raise RuntimeError("test_wrong_string failed. Number of failed tests: %d" % failed)


def main():
    print("-------------------------------------------------------")
    print(" Searching for inlined CPP macros in ABINIT src files  ")
    print("-------------------------------------------------------")
    exit_status = 0
    for top in find_src_dirs():
        assert os.path.isdir(top)
        for dirpath, dirnames, files in os.walk(top):
            for src in files:
                if not is_srcfile(dirpath, src): continue
                fpath = os.path.join(dirpath,src)
                with open(fpath, "rt") as fh:
                    for lno, line in enumerate(fh):
                        retcode = wrong_string(line)
                        if retcode:
                            print("Found INLINED MACRO at %s:%d:  %s " % (src, lno + 1, line))
                            exit_status += 1

    if exit_status > 0:
        err_msg = """
Please, avoid instructions like:

    if (npts > 0) ABI_FREE(arr)

When the code is compiled in profiling mode, indeed,
ABI_FREE expands to the set of Fortran instructions:

    deallocate(arr)
    call memocc_abi()

These instructions MUST be placed inside an "if then" "end if" block else you get:

    if (npts > 0) deallocate(arr)
    call memocc_abi()

that is cleary wrong!

For the time being, one has to use the more verbose form:

  if (npts > 0) then
    ABI_FREE(arr)
  end if

To deallocate an array only if it's already allocated, consider using the Safe FREE Macro:

    ABI_SFREE(arr)

that expands to:

    if (allocated(arr)) ABI_FREE(arr)

and is compatible with memory profiling.

This is the list of macros that cannot be inlined:

%(MACRO_NAMES)s
""" % globals()
        print(err_msg)

    return exit_status


if __name__ == "__main__":
    #test_wrong_string()
    sys.exit(main())



import numpy as np

nkpt = 168
nband = 38

eigs = np.zeros((nband, nkpt))

print(nband/8.)
nrows_eig = np.ceil(nband/8.)
print(nrows_eig)

with open("tw90_6_2o_DS4_EIG", "r") as fopen:
    for l, line in enumerate(fopen.readlines()):
        print(l, line)
        if not l:
            continue
        if (l - 1) % (nrows_eig + 1) == 0:
            continue
        else:
            row = int(np.floor((l - 1) % (nrows_eig + 1)) - 1)
            kpt = int(np.floor((l - 1) / (nrows_eig + 1)))
            print(row, kpt)
            for e, eig in enumerate(line.split()):
                eigs[row*8+e, kpt] = float(eig)

with open('band_struct.dat', 'w') as fopen:
    for b in range(nband):
        for k in range(nkpt):
            fopen.write("%.10f  %.10f\n" % (k, eigs[b, k]))
        fopen.write("\n")

for i in range(10):
    print(eigs[i])



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
"HAVE_LINALG_SCALAPACK",
]

#: List of keywords that are automatically added to all the tests of this suite.
keywords = [
"GWR",
]

#: List of input files
inp_files = [
"-t01.abi", # disabled for now
"-t02.abi", # disabled for now
"-t03.abi", # disabled for now
"-t04.abi", # disabled for now
"-t05.abi", # disabled for now
"-t06.abi", # disabled for now
"-t07.abi", # disabled for now
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite.
keywords = [
]

#: List of input files
inp_files = [
    # Constrained DFT
    "t01.abi",
    "t02.abi",
    "t03.abi",
    # Structure variable
    "t04.abi",
    # Optic
    "t05.abi",  # GGA-PBE nsppol=1
    "t06.abi",  # optic
    "t07.abi",  # GGA-PBE nsppol=2
    "t08.abi",  # optic
    "t09.abi",  # GGA-PBE PAW nsppol=1
    "t10.abi",  # optic
    "t11.abi",  # GGA-PBE PAW nsppol=2
    "t12.abi",  # optic
    "t13.abi",  # GGA-PBE NC BCC Iron ferromagnetic
    "t14.abi",  # GGA-PBE PAW BCC Iron ferromagnetic
    "t15.abi",  # check slight misalignment of rprim, with large tolsym
    "t16.abi",  # check slightly incorrect xred, with large tolsym
    # check slightly incorrect rprim and xred, yielding correction to tnons, although stil not tolerated.
    "t17.abi",
    # check slightly incorrect rprim and xred, yielding correction to tnons, tolerated.
    "t18.abi",
    "t19.abi",  # disable all checks thanks to expert_user
    "t20.abi",  # test treatment of inaccurate POSCAR file
    "t21.abi",  # test treatment of inaccurate POSCAR file
    "t22.abi",  # test different cellcharge for different images, algo pSIC
    "t23.abi",  # test treatment of inaccurate POSCAR file
    "t24.abi",  # test treatment of inaccurate POSCAR file
    "t25.abi",  # test treatment of inaccurate POSCAR file
    "t26.abi",  # test treatment of inaccurate POSCAR file
    "t27.abi",  # test treatment of inaccurate POSCAR file
    "t28.abi",  # test treatment of inaccurate POSCAR file
    "t29.abi",  # RMM-DIIS eigsolver for NC.
    "t30.abi",  # RMM-DIIS eigsolver for PAW.
    # GW/BSE
    "t31.abi",  # HF exchange checking q->0 terms
    "t32.abi",  # AC GW
    "t33.abi",  # GW 1RDM and related quantities
    "t34.abi",  # Same as t33.in but reading checkpoints
    "t35.abi",  # GW 1RDM and related quantities (using only Sigma_x)
    "t36.abi",  # GW 1RDM and related quantities but using Silicon
    "t37.abi",  # GW 1RDM and related quantities but using Silicon with diff. bdgw values
    "t40.abi",  # chi0 with inclvkb=2
    # DFPT
    "t41.abi",
    "t42.abi",
    "t43.abi",
    "t44.abi",  # test orbital magnetism with DDK wavefunctions on Ne atom
    "t46.abi",  # longwave GGA
    "t47.abi",  # metallic iron GGA-PBE PAW nsppol=2
    "t48.abi",  # optic
    "t49.abi",  # optic (same as t14 but prtlincompmatrixelements = 1)
    # Electron-phonon
    "t50.abi",
    "t51.abi",
    "t52.abi",
    "t53.abi",
    "t54.abi",
    "t55.abi",
    "t56.abi",
    "t57.abi",
    "t58.abi",
    "t59.abi",
    "t60.abi",
    "t61.abi",
    "t62.abi",
    "t63.abi",
    "t64.abi",
    "t65.abi",
    "t66.abi",
    "t67.abi",

    # More ground state
    "t71.abi",  # test cprj_update_lvl and nloc_alg options, istwfk=1
    "t72.abi",  # test cprj_update_lvl and nloc_alg options, istwfk>=2
    "t73.abi",  # test cprj_update_lvl options, forces and stress computed at the end of the run
    "t74.abi",  # test cprj_update_lvl options, forces computed during SCF iterations
    "t75.abi",  # test useylm=1 for NCPP with all KB energies being negative
    # test usepawu options (including negative ones), nsppol=nspinor=nspden=1
    "t76.abi",
    # test usepawu options (including negative ones), nsppol=2,nspden=2
    "t77.abi",
    # test usepawu options (including negative ones), nspinor=2,nspden=4
    "t78.abi",
    # test usepawu options (including negative ones), nspinor=2,nspden=1
    "t79.abi",

    # Spin dynamics in multibinit
    "t81.abi",  # set initial spin using rotation q-modulation
    "t82.abi",  # damping
    # New lattice mover in multibinit
    "t83.abi",  # Langevin NVT
    "t84.abi",  # Berendsen NVT
    "t85.abi",  # Velocity Verlet NVE
    "t86.abi",  # Spin lattice coupling, Only Oiju term activated.
    "t87.abi",  # Spin lattice coupling, Oiju and Tijuv.

    # test usepawu options with nspinor=2,nspden=4 and different pawxcdev
    "t88.abi", # LDA
    "t89.abi", # GGA

    # GS Coulomb cut-off
    "t90.abi",  # checkG Coulomb cut-off, large tolerance a.t.m.
    "t91.abi",  # occopt 9 tests on Si
    "t92.abi",  # check extended fpmd routines with low number of bands
    "t93.abi",  # energy, forces for PAW non-collinear, with usexcnhat=0
    "t94.abi",  # energy, stress for PAW non-collinear, with usexcnhat=0
    "t95.abi",  # test treatment of inaccurate POSCAR file
    "t96.abi",  # test treatment of inaccurate POSCAR file
    "t97.abi",  # test treatment of inaccurate POSCAR file
    "t98.abi",  # test treatment of inaccurate POSCAR file
    "t99.abi",  # test treatment of inaccurate POSCAR file

    # Optics with spin-orbit coupling
    "t100.abi", # Optical conductivity with spin-orbit coupling - ABINIT step
    "t101.abi", # Optical conductivity with spin-orbit coupling - CONDUCTI step
    "t102.abi", # X-ray core spectrocopy with spin-orbit coupling - ABINIT step
    "t103.abi", # X-ray core spectrocopy with spin-orbit coupling - CONDUCTI step
    # Optcell test
    "t104.abi", # Testing optcell 6 to relax 3rd vector not orthogonal to 1st and 2nd vectors

    # PAW+U and lruj/ujdet utilities
    "t105.abi", # Preliminary step for tests 106-109; generate WFK and DEN
    "t106.abi", # Hubbard U (macro_uj=1) test of ujdet subroutines
    "t107.abi", # Hund's J (macro_uj=4); preliminary step for t109
    "t108.abi", # Test of irdden and prtdosm input keywords
    "t109.abi", # Test of lruj post-processing w/ four LRUJ.nc files from t107

    # Lattice Wannier function
    # scdm-k method for lattice wannier function in anaddb (disentangle option 2)
    "t110.abi",
    # projWF method for lattice wannier function in anaddb (disentangle option 2)
    "t111.abi",
    
    # local orbital magnetic moments calculation.
    "t112.abi", # test prt_lorbmag   printing local orbital magnetic moments in atomic spheres

    # GS PAW Hybrid functionals
    "t120.abi",  # test PBE0 and related functionals with PAW
    # UPF2 format for norm-conserving pseudopotentials
    "t130.abi",  # UPF2
    "t131.abi",  # UPF2 with SOC
    "t132.abi",  # Forces using Beigi 2D cut-off
    # more DFPT
    "t140.abi",  # test orbital magnetism with DDK wavefunctions on AlP solid
    "t141.abi",  # test orbital magnetism with DDK wavefunctions on AlP solid with nspinor 2
    "t142.abi",  # test orbital magnetism with DDK wavefunctions on AlP solid with nsppol 2
    "t143.abi",  # test orbital magnetism with DDK wavefunctions and metallic sodium
    "t145.abi",  # test quadrupole calculation with all negative KB energies As PSP
    "t146.abi",  # test antisymmetric vector potential response and quadrupoles of HF molecule
    "t147.abi",  # test total vector potential response and quadrupoles of HF molecule
    "t148.abi",  # test flexoelectric tensor calculation with ffnl_lw=1
]



#!/usr/bin/env python
from abipy.abilab import abiopen
import abipy.data as abidata
import matplotlib.pyplot as plt
import numpy as np
from mpl_toolkits.axes_grid1 import make_axes_locatable

def get_projection(fb, l, typat, blist=None, fact=1.0):
    # This function was adapted from the plot_fatbands_typeview function
    e0 = fb.ebands.get_e0('fermie')
    x = np.arange(fb.nkpt)
   
    mybands = range(fb.ebands.mband) if blist is None else blist

    eigens = np.zeros((fb.nkpt, len(mybands)))
    width = np.zeros_like(eigens)

    for symbol in typat:
        for spin in range(fb.nsppol):
            wl_sbk = fb.get_wl_symbol(symbol) * (fact / 2)

            for ib, band in enumerate(mybands):
        
                eigens[:, ib] = fb.ebands.eigens[spin, :, band] - e0
                w = wl_sbk[l, spin, band]
                width[:, ib] += w

    return eigens, width

def plot_relative_projection(eigen, proj1, proj2, ax, x):

    # comptute relative projection and transform to [0,1] interval
    diff = proj1 - proj2
    diff -= np.amin(diff)
    maxproj = np.amax(diff)
    diff = diff/maxproj

    for ib in range(np.shape(diff)[-1]):
        ax0 =ax.scatter(range(x), eigen[:, ib], c=diff[:, ib], marker='o', s=80, cmap='seismic', edgecolor='k', zorder=2, vmin=0, vmax=1)

    return ax0


flist = ["tz2_2o_DS13_FATBANDS.nc", "tz2_2o_DS23_FATBANDS.nc"]

title = ['0GPa', '5GPa']
bands = [np.arange(36,40), np.arange(36,40)]

fig, ax = plt.subplots(1, len(flist), figsize=(5*len(flist), 6))

for j in range(len(flist)):
    # plot electronic bands
    data = abiopen(flist[j])
    data.ebands.set_fermie_to_vbm()
    data.ebands.plot(with_gaps=False, ylims=(-0.4, 0.8), ax=ax[j], show=False, fontsize=16, zorder=1)


    # compute Bi-p projections
    bi_eigen, bi_proj = get_projection(data, l=1, typat=['Bi'], blist=bands[j])
    # compute the sum of Te-p and I-p projections
    tei_eigen, tei_proj = get_projection(data, l=1, typat=['Te', 'I'], blist=bands[j])
    # compute and plot relative projection
    relplot = plot_relative_projection(bi_eigen, bi_proj, tei_proj, x=data.nkpt, ax=ax[j])

    ax[j].set_title(title[j])

    ax[j].set_xticks([0, 17, data.nkpt-1])
    ax[j].set_xticklabels(['0.5H', 'A', '0.5L'], fontsize=12)

divider = make_axes_locatable(ax[1])
cax = divider.append_axes("right", size="7%", pad=0.15)
cbar = plt.colorbar(relplot, cax=cax, ticks=[0, 1])
cbar.ax.set_yticklabels(['(Te+I)$_p$', 'Bi$_p$'])

plt.savefig('tz2_2_relative_projection.png')
plt.show()




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Z2 invariant calculation for BiTeI at 0 and 5 GPa

import os
import z2pack

if not os.path.exists('./results_tz2_3'):
    os.makedirs('./results_tz2_3')

# creating the System object
# We will create one for each pressure.
BiTeI_0gpa = z2pack.fp.System(
    input_files=['input_tz2_3/tz2_3_0gpa.abi', 'input_tz2_3/wannier90.win' ],
    kpt_fct=z2pack.fp.kpoint.abinit,
    kpt_path='tz2_3_0gpa.abi',
    command='abinit tz2_3_0gpa.abi >& log',
    executable='/bin/bash'
)

BiTeI_5gpa = z2pack.fp.System(
    input_files=['input_tz2_3/tz2_3_5gpa.abi', 'input_tz2_3/wannier90.win' ],
    kpt_fct=z2pack.fp.kpoint.abinit,
    kpt_path='tz2_3_5gpa.abi',
    command='abinit tz2_3_5gpa.abi >& log',
    executable='/bin/bash'
)

# calculating the WCC
# Invariant at fixed k_z planes
result_0 = z2pack.surface.run(system=BiTeI_0gpa, surface=lambda s, t: [s / 2, t,0.0], num_lines=20, save_file = './results_tz2_3/BiTeI_0.msgpack', load=True)
result_1 = z2pack.surface.run(system=BiTeI_0gpa, surface=lambda s, t: [s / 2, t,0.5], num_lines=20, save_file = './results_tz2_3/BiTeI_1.msgpack', load=True)
result_2 = z2pack.surface.run(system=BiTeI_5gpa, surface=lambda s, t: [s / 2, t,0.0], num_lines=20, save_file = './results_tz2_3/BiTeI_2.msgpack', load=True)
result_3 = z2pack.surface.run(system=BiTeI_5gpa, surface=lambda s, t: [s / 2, t,0.5], num_lines=20, save_file = './results_tz2_3/BiTeI_3.msgpack', load=True)

print('for 0 GPa:')
print('z2 topological invariant at kz = 0.0: {0}'.format(z2pack.invariant.z2(result_0)))
print('z2 topological invariant at kz = 0.5: {0}'.format(z2pack.invariant.z2(result_1)))
print('for 5 GPa:')
print('z2 topological invariant at kz = 0.0: {0}'.format(z2pack.invariant.z2(result_2)))
print('z2 topological invariant at kz = 0.5: {0}'.format(z2pack.invariant.z2(result_3)))



#!/usr/bin/env python3
"""
Script to plot the phonon band structure and compare with the LWF phonon band structure.
 COPYRIGHT
 Copyright (C) 1999-2021 ABINIT group (HeXu)
 This file is distributed under the terms of the
 GNU General Public Licence, see ~abinit/COPYING
 or http://www.gnu.org/copyleft/gpl.txt .
 For the initials of contributors, see ~abinit/doc/developers/contributors.txt .
"""

import os
import argparse
import numpy as np
import matplotlib.pyplot as plt

Ha_cmm1 = 219474.6313705


def plot_file(fname, ax, **kwargs):
    d = np.loadtxt(fname)
    nband = d.shape[1]-1
    for i in range(1, nband+1):
        ax.plot(d[:, 0], d[:, i]*Ha_cmm1, **kwargs)
    ax.set_xlim(d[0, 0], d[-1, 0])
    return ax


def plot_compare(prefix, ax):
    fname1 = prefix+"_PHFRQ"
    fname2 = prefix+"_lwf_PHFRQ"
    if os.path.exists(fname1):
        plot_file(fname1, ax=ax, color='blue', alpha=0.9)
    else:
        raise IOError("Cannot find the file "+fname1+"Please check.")
    if os.path.exists(fname2):
        plot_file(fname2, ax=ax, marker='o', color='green', alpha=0.7)
    ax.axhline(linestyle='--', color='gray')
    ax.set_ylabel("Frequency ($cm^{-1}$)")
    return ax


def main():
    parser = argparse.ArgumentParser(
        description="This is a script to plot the phonon band structure and compare to the lattice Wannier function phonon band structure by comparing the PHFRQ files. If there are two files {prefix}_lwf_PHFRQ, and {prefix}_PHFRQ, the band structures will be compared. If only the  {prefix}_PHFRQ exists, it will plot the full phonon band structure.")
    parser.add_argument("prefix", type=str,
                        help="The prefix of the PHFRQ files, e.g. with the prefix 'run', the run_PHFRQ file contains the phonon bands. ", default="fun")
    parser.add_argument("--output", "-o", type=str,
                        help="The name of the output figure file, should end with usual image file names, like .png, .pdf, etc. If not specified, no file will be saved", default=None)
    parser.add_argument("--show", "-s",
                        action="store_true",
                        help="whether to show the band structure to screen.",
                        default=True)
    args = parser.parse_args()
    _fig, ax = plt.subplots()
    plot_compare(prefix=args.prefix, ax=ax)
    if args.output is not None:
        plt.savefig(args.output)
    if args.show:
        plt.show()


if __name__ == "__main__":
    main()



#!/usr/bin/env python
import os
import matplotlib.pyplot as plt
import z2pack

result_0 = z2pack.io.load('results_tz2_3/BiTeI_0.msgpack')
result_1 = z2pack.io.load('results_tz2_3/BiTeI_1.msgpack')
result_2 = z2pack.io.load('results_tz2_3/BiTeI_2.msgpack')
result_3 = z2pack.io.load('results_tz2_3/BiTeI_3.msgpack')

# plotting
fig, ax = plt.subplots(2, 2, figsize=(10,10), constrained_layout=True)

# plot styling
fs = 15
for i in range(2):
    for j in range(2):
        ax[i,j].set_xlabel(r'$k_x$', fontsize=fs, labelpad=-5)
        ax[i,j].set_xticks([0, 1])
        ax[i,j].set_xticklabels([r'$0$', r'$\pi/a_x$'])
ax[0,0].set_ylabel(r'$\bar{y}$', rotation='horizontal', fontsize=fs)
ax[0,0].set_title(
    r'$0 GPa, k_z=0.0, \Delta={}$'.format(z2pack.invariant.z2(result_0)),
    fontsize=fs
)
ax[0,1].set_title(
    r'$ 0 GPa, k_z=0.5, \Delta={}$'.format(z2pack.invariant.z2(result_1)),
    fontsize=fs
)
ax[1,0].set_ylabel(r'$\bar{y}$', rotation='horizontal', fontsize=fs)
ax[1,0].set_title(
    r'$5 GPa, k_z=0.0, \Delta={}$'.format(z2pack.invariant.z2(result_2)),
    fontsize=fs
)
ax[1,1].set_title(
    r'$ 5 GPa, k_z=0.5, \Delta={}$'.format(z2pack.invariant.z2(result_3)),
    fontsize=fs
)
# plotting the WCC evolution
z2pack.plot.wcc(result_0, axis=ax[0,0])
z2pack.plot.wcc(result_1, axis=ax[0,1])
z2pack.plot.wcc(result_2, axis=ax[1,0])
z2pack.plot.wcc(result_3, axis=ax[1,1])
#z2pack.plot.chern(result_1, axis=ax[0,2])
#z2pack.plot.chern(result_3, axis=ax[1,2])


#if not os.path.isdir('plots'):
#    os.mkdir('plots')

plt.savefig('tz2_3_hwcc.png', bbox_inches='tight')
plt.show()



#!/usr/bin/env python
# ======================================================================
# == Python script to remove robodoc sections, e.g. PARENTS           ==
# ==  Usage: simply launch the script from the ABINIT root folder     ==
# ==  The keyword of the section can be changed,                      ==
# ==  by replacing its keystring below                                ==
# ==                                                                  ==
# ==  X.Gonze - July 19 2022 starting from     M. Torrent - June 2011 ==
# ======================================================================
from __future__ import print_function

import os
import re

#Define keystring
keystring='PARENTS'
#keystring='CHILDREN'

re_srcfile = re.compile("\.([Ff]|[Ff]90|h)$")

print( )

#Initialize counters
file_total_count=0
file_write_wrong_count=0

#Loop over files in src folder
#-----------------------------
for (root, dirs, files) in os.walk("src"):
  for src in files:
    if ( re_srcfile.search(src) ):
      file_total_count +=1
      filename=os.path.join(root,src)
      with open(filename, "r") as fh: 
        src_data = fh.readlines()

#     1- look for '!!'+keystring in the file and identify whether it is a valid keystring section
#     ------------------------------------------------------------------------------------
#     Loop over lines in the file
      found_keystring=False
      found_keystring_section=False
      for line in src_data:
#       Eliminate whitespaces, add blank at beginning
#       print ('Line: %s' % (line))
        line = re.sub(" ","",line)
#       print ('Line: %s' % (line))
#       print(line.find("!!"+keystring+"\n"))
        if line.find("!!"+keystring+"\n") != -1:
          found_keystring=True
#         print ('File %s, found keystring statement' % (filename))
        if found_keystring:
#         print (' found_keystring is True, looking for section')
          if line.find("!!") == -1: 
            found_keystring=False
#           print ('File %s, did not find keystring section' % (filename))
#         print(line.find("!!\n"))
          if line.find("!!\n") != -1: 
            found_keystring_section=True
#           print ('File %s, found keystring section' % (filename))
            break
#         print (' found_keystring is True, this line is inside section')
        if found_keystring_section: break
#     print ('File %s, examined for keystring sections, finished search' % (filename))

#     2- if keystring statements found, suppress them
#     ----------------------------------------------
      if found_keystring_section:
        ErrorEncountered=False
#       Write message
#       print ('File %s: found at least one keystring section\n' % (filename))
#       Open a temporary file for writing
        filenametmp=filename+'.tmp'

        try:
          filout=open(filenametmp,'w')
        except:
          print ('File %s, error: could not open tmp file !' % (filename))
          ErrorEncountered=True

        if not ErrorEncountered:
#         print ('File %s, succeeded to open tmp file !' % (filename))
#         Loop over lines in the file
          found_keystring=False
          write_newline=True
          for line in src_data:

#           Eliminate whitespaces, add blank at beginning
#           print ('Line: %s' % (line))
            line_wo_blks = re.sub(" ","",line)
#           print ('Line: %s' % (line_wo_blks))

            is_keystring_line=False
            if line_wo_blks.find("!!"+keystring+"\n") != -1:
              found_keystring=True
              is_keystring_line=True
              newline=line
              write_newline=False
#             print ('File %s, found keystring statement' % (filename))
            if not found_keystring:
              write_newline=True
              newline=line
#             print ('File %s, not inside keystring section' % (filename))
            if found_keystring and not is_keystring_line:
              end_keystring=False
#             print (' found_keystring is True, looking for section')
#             Abnormal end of keystring section : write stored lines
              if line_wo_blks.find("!!") == -1:  
                end_keystring=True
                found_keystring=False
                write_newline=True
                newline=newline+line
#               print ('File %s, abnormal end of keystring section, will write stored newline' % (filename))
#             Normal end of keystring section
              if line_wo_blks.find("!!\n") != -1:  
                end_keystring=True
                found_keystring=False
                write_newline=False
#               print ('File %s, found keystring section, do not write' % (filename))
#             Inside keystring section : store the line
              if not end_keystring:
                write_newline=False
                newline=newline+line
#               print ('File %s, inside keystring section, do not write' % (filename))
           
#           Write the modified line
            if write_newline:
#             print ('File %s, will write newline' % (filename))
              try:
                filout.write(newline)
              except:
                print ('File %s, error: could not write into tmp file !' % (filename))
                ErrorEncountered=True
                break

#         Close the temporary file
          filout.close()

#         Replace current file by temporary file
          if not ErrorEncountered:
            try:
              os.system('mv -f '+filenametmp+' '+filename)
              file_write_wrong_count +=1
            except:
              print ('File %s, error: could not move tmp file !' % (filename))

#Print final message
#-------------------
if file_write_wrong_count==0:
  print ('No file modified !')
else:
  print ('---------------------------------------------------')
  print ('%d/%d file(s) modified !' %  (file_write_wrong_count,file_total_count))
